@@ -24,7 +24,7 @@ def formula_per_sample(df, metadata, group, path):
     # Plotting the number of molecular formulas per each of the samples
     p = sns.barplot(x="SampleID",
                     y="Counts",
-                    hue=group,
+                    hue=group[0],
                     data=stats_per_sample,
                     order=stats_per_sample.sort_values(by='Counts')['SampleID'],
                     saturation=0.7,
